import colors
import requests


class WeatherDisplay:
    def __init__(self, characterDisplay, topRow):
        self.characterDisplay = characterDisplay
        self.topRow = topRow
        self.currentTemperature = [9, 9]
        self.color = colors.BLUE
        self.weatherFile = 'weather.txt'

    def showWeather(self):
        try:
            self.showTemperature(
                self.getTemperatureCharacters(self.getTemperature()))
        except requests.exceptions.ConnectionError:
            print('connection error', flush=True)
            self.characterDisplay.clearRow(self.topRow)
        except requests.exceptions.Timeout:
            print('timeout', flush=True)
            self.characterDisplay.clearRow(self.topRow)

    def showTemperature(self, temperature):
        if temperature != self.currentTemperature:
            self.characterDisplay.clearRow(self.topRow)

            start = 13 if (
                len(temperature) == 2 and temperature[0] == '-') or len(temperature) == 1 else 9

            for c in temperature:
                if c == '-':
                    self.characterDisplay.displayNegative(
                        start-3, self.topRow, self.color)
                else:
                    self.characterDisplay.displayDigit(
                        start, self.topRow, c, self.color)
                    start = start + 4

            self.currentTemperature = temperature

    def getTemperature(self):
        # TODO - don't use a file left around from a previous run
        # TODO - clear temp on errors from updater
        try:
            with open(self.weatherFile) as file:
                return int(file.readline().strip())
        except Exception as e:
            print(e)
            return 0

    def getTemperatureCharacters(self, temperature):
        return list(str(round(temperature)))
